<template>
  <div>
    <div class="wrapper">
      <div class="question">
        <p class="surveyquestion">{{ question.text }}</p>
        <div class="surveyanswercontainer">
          <div class="surveyinput">
            <div v-if="question.type === 'rating'">
              <div class="surveydescription">Select a number from 1 to 5 (1 being poor and 5 being amazing).</div><br>
              <div v-if="question.answer">
                <div
                  v-for="number in 5"
                  v-model="question.answer"
                  :class="['surveyanswer' + number, {surveyanswerinactive:number != question.answer}]"
                  class="ratingQuestion circleBase surveyanswer"
                  @click="makeSelection(number)" >{{ number }}
                </div>
              </div>
              <div v-else>
                <div
                  v-for="number in 5"
                  v-model="question.answer"
                  :class="['surveyanswer' + number]"
                  class="ratingQuestion circleBase surveyanswer"
                  @click="makeSelection(number)" >{{ number }}
                </div>
              </div>
            </div>
            <div v-else-if="question.type === 'single_choice'">
              <div class="surveydescription">Please select one.</div><br>
              <div class="radios">
                <div
                  v-for="option in question.options"
                  class="roundedOne">
                  <input
                    :id="option"
                    :value="option"
                    v-model="selectedOption"
                    :checked="question.answer_title === option"
                    type="radio"
                    @change="makeSelection(option)">
                  <label
                    :for="option"
                    class="radio">
                    <span>{{ option }}</span>
                  </label>
                  <br>
                  <div v-if="option === 'Other'" >
                    <input
                      v-show="selectedOption === 'Other'"
                      :value="other"
                      style="margin: 15px 0 0 42px; background: #A9A8A8; color: white;"
                      type="text"
                      @change="makeOtherSelection($event)">
                  </div>
                </div>
              </div>
              <br>
            </div>
            <div v-else-if="question.type === 'text_area'">
              <textarea
                v-model="question.answer"
                name="surveyanswer"
                @change="makeSelection(question.answer)"/>
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>
</template>

<script>
export default {
  props: {
    question:null,
    account:null,
    other:null
  },
    data() {
      return {
        selectedOption:null,
        otherField:this.other
    };
  },
  updated(){
    this.selectedOption = this.question.answer_title;
  },
  methods:{
    makeSelection(answerValue){
      let answer_title = answerValue;
      if(this.selectedOption === "Other" && this.question.type === "single_choice"){
        answer_title = "Other";
        answerValue = this.otherField;
      }
      // update state
      this.question.answer = answerValue;
      this.question.answer_title = answer_title;

      // build object to presist state and update db
      let answer = {
        "session":this.account.session,
        "answer":answerValue,
        "individual_account_id":this.account.accountId,
        "question_id":this.question.id,
        "answer_title":answer_title
      };
      let self = this;
      app.api.Post("survey", answer)
        .then( Response => {
        })
        .catch( x => app.Message( x.error, "error" ) );
    },
    makeOtherSelection(event){
      this.otherField = event.target.value;
      this.makeSelection(event.target.value);
    }
  }
};
</script>